==> nextcloud-27.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/ar.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "المُعامل المُعطى غير مقبول",
    "The given regular expression is invalid" : "التعبير النظامي RE  المُعطى غير مقبول",
    "The given file size is invalid" : "حجم الملف المُعطى غير مقبول",
    "The given tag id is invalid" : "اللصيقة tag المُعطاة غير مقبولة",
    "The given IP range is invalid" : "نطاق العنوان IP المُعطى غير مقبول.",
    "The given IP range is not valid for IPv4" : "نطاق العنوان IP المُعطى غير مقبول بالنسبة لـ IPv4.",
    "The given IP range is not valid for IPv6" : "نطاق العنوان IP المُعطى غير مقبول بالنسبة لـ IPv6.",
    "The given time span is invalid" : "الفترة الزمنية المُعطاة غير مقبولة",
    "The given start time is invalid" : "وقت البداية المُعطى غير مقبول.",
    "The given end time is invalid" : "وقت النهاية المُعطى غير مقبول.",
    "The given group does not exist" : "المجموعة المُعطاة غير موجودة.",
    "File" : "ملف",
    "File created" : "ملف مُنشأ",
    "File updated" : "ملف مُحدّث",
    "File renamed" : "ملف مُعاد تسميته",
    "File deleted" : "ملف محذوف",
    "File accessed" : "ملف تم الوصول إليه",
    "File copied" : "ملف منسوخ",
    "Tag assigned" : "لصيقة مُسندة",
    "Someone" : "شخصٌ ما",
    "%s created %s" : "%s مُنشأ %s",
    "%s modified %s" : "%s مُعدّل %s",
    "%s deleted %s" : "%s مُلغىً %s",
    "%s accessed %s" : "%s تم الوصول إليه %s",
    "%s renamed %s" : "%s مُعاد تسميته %s",
    "%s copied %s" : "%s منسوخ %s",
    "%s assigned %s to %s" : "%s مُسند %s إلى %s",
    "Operation #%s does not exist" : "العملية #%s غير موجودة",
    "Entity %s does not exist" : "الكيان %s غير موجود",
    "Entity %s is invalid" : "الكيان %s غير مقبول",
    "No events are chosen." : "لم يتم اختيار أي أحدث.",
    "Entity %s has no event %s" : "الكيان %s ليس له أحداث %s",
    "Operation %s does not exist" : "العملية %s غير موجودة",
    "Operation %s is invalid" : "العملية%sغير موجودة",
    "At least one check needs to be provided" : "يجب تقديم اختيار واحد على الأقل",
    "The provided operation data is too long" : "تشغيل البيانات المطلوب كبير جدا",
    "Invalid check provided" : "الاختيار المقدم غير صالح",
    "Check %s does not exist" : "تحقق من%s غير موجود",
    "Check %s is invalid" : "تحقق من%sغير صالح",
    "Check %s is not allowed with this entity" : "التحقق من %s غير مسموح به مع هذا الكيان",
    "The provided check value is too long" : "قيمة التحقق المقدمة طويلة جدًا",
    "Check #%s does not exist" : "تحقق من#%s غير موجود",
    "Check %s is invalid or does not exist" : "التحقق من %s فهو غير صالح أو غير موجود",
    "Flow" : "تدفُّق Flow",
    "Nextcloud workflow engine" : "محرك سير عمل نكست كلود",
    "Select a filter" : "اختر عامل تصفية",
    "Select a comparator" : "اختر أساس المقارنة",
    "Remove filter" : "إزالة الفلتر",
    "Select a file type" : "اختر نوع الملف",
    "e.g. httpd/unix-directory" : "على سبيل المثال httpd/unix-directory",
    "Folder" : "مجلد",
    "Images" : "صور",
    "Office documents" : "مستندات المكتب",
    "PDF documents" : "مستندات PDF",
    "Custom MIME type" : "نوع MIME مخصص",
    "Custom mimetype" : "أنواع ملفات مخصصة",
    "Please enter a valid time span" : "الرجاء إدخال نطاق زمني صالح",
    "Select a request URL" : "حدد عنوان URL الخاص بالطلب",
    "Files WebDAV" : "ملفات امتدادات ويب داف \"WebDAV\"",
    "Custom URL" : "عنوان URL مخصص",
    "Select a user agent" : "اختر وكيل مستخدم",
    "Android client" : "عميل أندرويد",
    "iOS client" : "عميل نظام التشغيل آي أو إس \"iOS\"",
    "Desktop client" : "تطبيق سطح المكتب",
    "Thunderbird & Outlook addons" : "إضافات ثندربيرد و أوت لوك",
    "Custom user agent" : "وكيل مستخدم مخصص",
    "Select a trigger" : "حدد مشغل",
    "At least one event must be selected" : "يجب اختيار حدث واحد على الأقل",
    "Add new flow" : "إضافة مسار دفق جديد",
    "When" : "متى",
    "and" : "و",
    "Add a new filter" : "إضافة فلتر جديد",
    "Cancel" : "إلغاء",
    "Delete" : "حذف ",
    "The configuration is invalid" : "التكوين غير صالح",
    "Active" : "فعال",
    "Save" : "حفظ",
    "Available flows" : "مسارات الدفق المتاحة",
    "For details on how to write your own flow, check out the development documentation." : "للحصول على تفاصيل حول كيفية كتابة مسارات الدفق الخاص بك، تحقق من وثائق التطوير.",
    "More flows" : "المزيد من مسارات الدفق",
    "Browse the App Store" : "إستعرض متجر التطبيقات",
    "Show less" : "عرض أقل",
    "Show more" : "عرض المزيد",
    "Configured flows" : "مسار الدفق المُعد",
    "Your flows" : "مسار الدفق الخاص بك",
    "matches" : "متوافق",
    "does not match" : "غير متوافق",
    "is" : "يكون",
    "is not" : "ليس",
    "File name" : "اسم ملف",
    "File MIME type" : "الملف من النوع MIME\"امتدادات بريد الإنترنت متعددة الأغراض \"",
    "File size (upload)" : "حجم الملف (الرفع)",
    "less" : "أقل",
    "less or equals" : "أقل من أو يساوي",
    "greater or equals" : "أكبر أو يساوي",
    "greater" : "أكبر من",
    "Request remote address" : "العنوان البعيد الخاص بالطلب",
    "matches IPv4" : "متوافق مع بروتوكول الانترنت الاصدار الرابع \"IPv4\"",
    "does not match IPv4" : "غير متوافق مع بروتوكول الانترنت الاصدار الرابع \"IPv4\"",
    "matches IPv6" : "متوافق مع بروتوكول الانترنت الاصدار السادس \"IPv6\"",
    "does not match IPv6" : "غير متوافق مع بروتوكول الانترنت الاصدار الرابع \"IPv6\"",
    "File system tag" : "وسم ملف النظام",
    "is tagged with" : "موسومة بـ",
    "is not tagged with" : "غير موسومة بـ",
    "Request URL" : "عنوان محدد موقع الموارد المُوحّد \"URL\" الخاص بالطلب",
    "Request time" : "وقت الطلب",
    "between" : "بين",
    "not between" : "ليس بين",
    "Request user agent" : "وكيل المستخدم الخاص بالطلب",
    "User group membership" : "عضوية مجموعة المستخدمين",
    "is member of" : "عضو فى",
    "is not member of" : "ليس عضو فى",
    "Predefined URLs" : "عناوين محدد موقع الموارد المُوحّد \"URLs\" المحددة مسبقا",
    "Others" : "آخرون"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-30.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/ar.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "المُعامل المُعطى غير مقبول",
    "The given regular expression is invalid" : "التعبير النمطي Regex المدخل غير صالح",
    "The given file size is invalid" : "حجم الملف المُعطى غير مقبول",
    "The given tag id is invalid" : "الوسم  المعطى غير مقبول",
    "The given IP range is invalid" : "نطاق العنوان IP المُعطى غير مقبول.",
    "The given IP range is not valid for IPv4" : "نطاق العنوان IP المُعطى غير مقبول بالنسبة لـ IPv4.",
    "The given IP range is not valid for IPv6" : "نطاق العنوان IP المُعطى غير مقبول بالنسبة لـ IPv6.",
    "The given time span is invalid" : "الفترة الزمنية المُعطاة غير مقبولة",
    "The given start time is invalid" : "وقت البداية المُعطى غير مقبول.",
    "The given end time is invalid" : "وقت النهاية المُعطى غير مقبول.",
    "The given group does not exist" : "المجموعة المُعطاة غير موجودة.",
    "File" : "ملف",
    "File created" : "ملف مُنشأ",
    "File updated" : "ملف مُحدّث",
    "File renamed" : "ملف مُعاد تسميته",
    "File deleted" : "ملف محذوف",
    "File accessed" : "ملف تم الوصول إليه",
    "File copied" : "ملف منسوخ",
    "Tag assigned" : "وسم تم تعيينه",
    "Someone" : "شخصٌ ما",
    "%s created %s" : "%s مُنشأ %s",
    "%s modified %s" : "%s مُعدّل %s",
    "%s deleted %s" : "%s مُلغىً %s",
    "%s accessed %s" : "%s تم الوصول إليه %s",
    "%s renamed %s" : "%s مُعاد تسميته %s",
    "%s copied %s" : "%s منسوخ %s",
    "%s assigned %s to %s" : "%s مُسند %s إلى %s",
    "Operation #%s does not exist" : "العملية #%s غير موجودة",
    "Entity %s does not exist" : "الكيان %s غير موجود",
    "Entity %s is invalid" : "الكيان %s غير مقبول",
    "No events are chosen." : "لم يتم اختيار أي أحدث.",
    "Entity %s has no event %s" : "الكيان %s ليس له أحداث %s",
    "Operation %s does not exist" : "العملية %s غير موجودة",
    "Operation %s is invalid" : "العملية%sغير موجودة",
    "At least one check needs to be provided" : "يجب تقديم اختيار واحد على الأقل",
    "The provided operation data is too long" : "تشغيل البيانات المطلوب كبير جدا",
    "Invalid check provided" : "الاختيار المقدم غير صالح",
    "Check %s does not exist" : "تحقق من%s غير موجود",
    "Check %s is invalid" : "تحقق من%sغير صالح",
    "Check %s is not allowed with this entity" : "التحقق من %s غير مسموح به مع هذا الكيان",
    "The provided check value is too long" : "قيمة التحقق المقدمة طويلة جدًا",
    "Check #%s does not exist" : "تحقق من#%s غير موجود",
    "Check %s is invalid or does not exist" : "التحقق من %s فهو غير صالح أو غير موجود",
    "Flow" : "أتمتة سير العمل",
    "Nextcloud workflow engine" : "محرك أتمتة سير العمل لنكست كلاود",
    "Select a filter" : "اختر عامل تصفية",
    "Select a comparator" : "اختر أساس المقارنة",
    "Remove filter" : "إزالة عامل التصفية",
    "Select a file type" : "اختر نوع الملف",
    "e.g. httpd/unix-directory" : "على سبيل المثال httpd/unix-directory",
    "Folder" : "مجلد",
    "Images" : "صور",
    "Office documents" : "مستندات المكتب",
    "PDF documents" : "مستندات PDF",
    "Custom MIME type" : "نوع MIME مخصص",
    "Custom mimetype" : "أنواع ملفات مخصصة",
    "Please enter a valid time span" : "الرجاء إدخال نطاق زمني صالح",
    "Select a request URL" : "حدد عنوان URL الخاص بالطلب",
    "Files WebDAV" : "ملفات  WebDAV",
    "Custom URL" : "عنوان URL مخصص",
    "Select a user agent" : "اختر وكيل مستخدم",
    "Android client" : "عميل أندرويد",
    "iOS client" : "عميل نظام التشغيل  iOS",
    "Desktop client" : "تطبيق سطح المكتب",
    "Thunderbird & Outlook addons" : "إضافات ثندربيرد و أوت لوك",
    "Custom user agent" : "وكيل مستخدم مخصص",
    "Select groups" : "إختَر مجموعةً",
    "Groups" : "المجموعات",
    "Type to search for group …" : "أُكتُب اسم المجموعة التي تبحث عنها ...",
    "Select a trigger" : "حدد مشغل",
    "At least one event must be selected" : "يجب اختيار حدث واحد على الأقل",
    "Add new flow" : "إضافة أتمتة سير عمل جديد",
    "When" : "متى",
    "and" : "و",
    "Add a new filter" : "إضافة عامل تصفية جديد",
    "Cancel" : "إلغاء",
    "Delete" : "حذف ",
    "The configuration is invalid" : "التكوين غير صالح",
    "Active" : "فعال",
    "Save" : "حفظ",
    "Available flows" : "أتمتة سير العمل المتاحة",
    "For details on how to write your own flow, check out the development documentation." : "للحصول على تفاصيل حول كيفية تطوير أتمتة سير العمل الخاص بك، تحقق من وثائق التطوير.",
    "No flows installed" : "لم يتم تثبيت أي أتمتة لسير العمل",
    "Ask your administrator to install new flows." : "أطلب من المشرف تثبيت أتمتة سير عمل جديدة .",
    "More flows" : "المزيد من أتمتة سير العمل",
    "Browse the App Store" : "إستعرض متجر التطبيقات",
    "Show less" : "عرض أقل",
    "Show more" : "عرض المزيد",
    "Configured flows" : "أتمتة سير العمل المضافة",
    "Your flows" : "أتمتة سير العمل الخاص بك",
    "No flows configured" : "لم تتم تهيئة أي أتمتة لسير العمل",
    "matches" : "متوافق",
    "does not match" : "غير متوافق",
    "is" : "يكون",
    "is not" : "ليس",
    "File name" : "اسم ملف",
    "File MIME type" : "ملف من النوع MIME",
    "File size (upload)" : "حجم الملف (الرفع)",
    "less" : "أقل",
    "less or equals" : "أقل من أو يساوي",
    "greater or equals" : "أكبر أو يساوي",
    "greater" : "أكبر من",
    "Request remote address" : "العنوان البعيد الخاص بالطلب",
    "matches IPv4" : "متوافق مع بروتوكول الانترنت الاصدار الرابع \"IPv4\"",
    "does not match IPv4" : "غير متوافق مع بروتوكول الانترنت الاصدار الرابع \"IPv4\"",
    "matches IPv6" : "متوافق مع بروتوكول الانترنت الاصدار السادس \"IPv6\"",
    "does not match IPv6" : "غير متوافق مع بروتوكول الانترنت الاصدار الرابع \"IPv6\"",
    "File system tag" : "وسم ملف النظام",
    "is tagged with" : "موسوم بـ",
    "is not tagged with" : "غير موسوم بـ",
    "Request URL" : "عنوان محدد موقع الموارد المُوحّد \"URL\" الخاص بالطلب",
    "Request time" : "وقت الطلب",
    "between" : "بين",
    "not between" : "ليس بين",
    "Request user agent" : "وكيل المستخدم الخاص بالطلب",
    "Group membership" : "عضوية المجموعة",
    "is member of" : "عضو فى",
    "is not member of" : "ليس عضو فى",
    "User group membership" : "عضوية مجموعة المستخدمين"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
